==> mandelbulber2_2.10.orig.tar.gz: mandelbulber2-2.10/src/test.hpp <==
/**
 * Mandelbulber v2, a 3D fractal generator       ,=#MKNmMMKmmßMNWy,
 *                                             ,B" ]L,,p%%%,,,§;, "K
 * Copyright (C) 2016-17 Mandelbulber Team     §R-==%w["'~5]m%=L.=~5N
 *                                        ,=mm=§M ]=4 yJKA"/-Nsaj  "Bw,==,,
 * This file is part of Mandelbulber.    §R.r= jw",M  Km .mM  FW ",§=ß., ,TN
 *                                     ,4R =%["w[N=7]J '"5=],""]]M,w,-; T=]M
 * Mandelbulber is free software:     §R.ß~-Q/M=,=5"v"]=Qf,'§"M= =,M.§ Rz]M"Kw
 * you can redistribute it and/or     §w "xDY.J ' -"m=====WeC=\ ""%""y=%"]"" §
 * modify it under the terms of the    "§M=M =D=4"N #"%==A%p M§ M6  R' #"=~.4M
 * GNU General Public License as        §W =, ][T"]C  §  § '§ e===~ U  !§[Z ]N
 * published by the                    4M",,Jm=,"=e~  §  §  j]]""N  BmM"py=ßM
 * Free Software Foundation,          ]§ T,M=& 'YmMMpM9MMM%=w=,,=MT]M m§;'§,
 * either version 3 of the License,    TWw [.j"5=~N[=§%=%W,T ]R,"=="Y[LFT ]N
 * or (at your option)                   TW=,-#"%=;[  =Q:["V""  ],,M.m == ]N
 * any later version.                      J§"mr"] ,=,," =="""J]= M"M"]==ß"
 *                                          §= "=C=4 §"eM "=B:m|4"]#F,§~
 * Mandelbulber is distributed in            "9w=,,]w em%wJ '"~" ,=,,ß"
 * the hope that it will be useful,                 . "K=  ,=RMMMßM"""
 * but WITHOUT ANY WARRANTY;                            .'''
 * without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with Mandelbulber. If not, see <http://www.gnu.org/licenses/>.
 *
 * ###########################################################################
 *
 * Authors: Sebastian Jennen (jenzebas@gmail.com), Krzysztof Marczak (buddhi1980@gmail.com)
 *
 * class for testing mandelbulber functionality on the cli
 */

#ifndef MANDELBULBER2_SRC_TEST_HPP_
#define MANDELBULBER2_SRC_TEST_HPP_

#include <QWidget>
#include <QtTest/QtTest>

class Test : public QObject
{
	Q_OBJECT
public:
	enum enumTestMode
	{
		simpleTestMode,
		benchmarkTestMode
	};
	Test(enumTestMode testMode_) { testMode = testMode_; }
	bool IsBenchmarking() const { return testMode == enumTestMode::benchmarkTestMode; }
private:
	static QString testFolder();
	enumTestMode testMode;

	void renderExamples();
	void testFlight();
	void testKeyframe();
	void renderSimple();

private slots:
	static void init();
	static void cleanup();
	void renderExamplesWrapper();
	void netrender();
	void testFlightWrapper();
	void testKeyframeWrapper();
	void renderSimpleWrapper();
};

#endif /* MANDELBULBER2_SRC_TEST_HPP_ */

==> mandelbulber2-2.33.tar.gz: mandelbulber2-2.33/src/test.hpp <==
/**
 * Mandelbulber v2, a 3D fractal generator       ,=#MKNmMMKmmßMNWy,
 *                                             ,B" ]L,,p%%%,,,§;, "K
 * Copyright (C) 2016-20 Mandelbulber Team     §R-==%w["'~5]m%=L.=~5N
 *                                        ,=mm=§M ]=4 yJKA"/-Nsaj  "Bw,==,,
 * This file is part of Mandelbulber.    §R.r= jw",M  Km .mM  FW ",§=ß., ,TN
 *                                     ,4R =%["w[N=7]J '"5=],""]]M,w,-; T=]M
 * Mandelbulber is free software:     §R.ß~-Q/M=,=5"v"]=Qf,'§"M= =,M.§ Rz]M"Kw
 * you can redistribute it and/or     §w "xDY.J ' -"m=====WeC=\ ""%""y=%"]"" §
 * modify it under the terms of the    "§M=M =D=4"N #"%==A%p M§ M6  R' #"=~.4M
 * GNU General Public License as        §W =, ][T"]C  §  § '§ e===~ U  !§[Z ]N
 * published by the                    4M",,Jm=,"=e~  §  §  j]]""N  BmM"py=ßM
 * Free Software Foundation,          ]§ T,M=& 'YmMMpM9MMM%=w=,,=MT]M m§;'§,
 * either version 3 of the License,    TWw [.j"5=~N[=§%=%W,T ]R,"=="Y[LFT ]N
 * or (at your option)                   TW=,-#"%=;[  =Q:["V""  ],,M.m == ]N
 * any later version.                      J§"mr"] ,=,," =="""J]= M"M"]==ß"
 *                                          §= "=C=4 §"eM "=B:m|4"]#F,§~
 * Mandelbulber is distributed in            "9w=,,]w em%wJ '"~" ,=,,ß"
 * the hope that it will be useful,                 . "K=  ,=RMMMßM"""
 * but WITHOUT ANY WARRANTY;                            .'''
 * without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with Mandelbulber. If not, see <http://www.gnu.org/licenses/>.
 *
 * ###########################################################################
 *
 * Authors: Sebastian Jennen (jenzebas@gmail.com), Krzysztof Marczak (buddhi1980@gmail.com)
 *
 * class for testing mandelbulber functionality on the cli
 */

#ifndef MANDELBULBER2_SRC_TEST_HPP_
#define MANDELBULBER2_SRC_TEST_HPP_

#include <QWidget>
#include <QtTest/QtTest>

class Test : public QObject
{
	Q_OBJECT
public:
	enum enumTestMode
	{
		simpleTestMode,
		benchmarkTestMode
	};
	Test(enumTestMode _testMode, int _difficulty = 10, QString _exampleOutputPath = "")
	{
		testMode = _testMode;
		difficulty = _difficulty;
		exampleOutputPath = _exampleOutputPath;
	}
	bool IsBenchmarking() const { return testMode == enumTestMode::benchmarkTestMode; }

private:
	static QString testFolder();
	enumTestMode testMode;

	/* difficulty for the benchmark: 1 -> very easy, > 20 -> very hard, 10 -> default */
	int difficulty;

	QString exampleOutputPath;

	void renderExamples() const;
	void testFlight() const;
	void testKeyframe() const;
	void renderSimple() const;
	void renderImageSave() const;

private slots:
	static void init();
	static void cleanup();
	void renderExamplesWrapper() const;
	void netrender();
	void testFlightWrapper() const;
	void testKeyframeWrapper() const;
	void renderSimpleWrapper() const;
	void testImageSaveWrapper() const;
};

#endif /* MANDELBULBER2_SRC_TEST_HPP_ */
